@@ -8,7 +8,7 @@ pub fn app() -> App<'static> {
         .about(env!("CARGO_PKG_DESCRIPTION"))
         .arg(
             Arg::new("commit-file-path")
-                .about(
+                .help(
                     "Path to a temporary file that contains the commit message written by the \
                      developer",
                 )
@@ -18,7 +18,7 @@ pub fn app() -> App<'static> {
         .arg(
             Arg::new("copy-message-to-clipboard")
                 .long("copy-message-to-clipboard")
-                .about("On lint failure copy the message to clipboard")
+                .help("On lint failure copy the message to clipboard")
                 .env("GIT_MIT_COPY_MESSAGE_TO_CLIPBOARD")
                 .takes_value(true)
                 .default_value("true"),
